==> zio-aws-ec2_2.12-5.17.103.1-sources.jar: zio/aws/ec2/model/DeregisterInstanceTagAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeregisterInstanceTagAttributeRequest(
    includeAllTagsOfInstance: Option[Boolean] = None,
    instanceTagKeys: Option[Iterable[String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest = {
    import DeregisterInstanceTagAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
      .builder()
      .optionallyWith(
        includeAllTagsOfInstance.map(value => value: java.lang.Boolean)
      )(_.includeAllTagsOfInstance)
      .optionallyWith(
        instanceTagKeys.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.instanceTagKeys)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly =
    zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest
      .wrap(buildAwsValue())
}
object DeregisterInstanceTagAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest =
      zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest(
        includeAllTagsOfInstance.map(value => value),
        instanceTagKeys.map(value => value)
      )
    def includeAllTagsOfInstance: Option[Boolean]
    def instanceTagKeys: Option[List[String]]
    def getIncludeAllTagsOfInstance: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("includeAllTagsOfInstance", includeAllTagsOfInstance)
    def getInstanceTagKeys: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("instanceTagKeys", instanceTagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
  ) extends zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly {
    override val includeAllTagsOfInstance: Option[Boolean] =
      scala.Option(impl.includeAllTagsOfInstance()).map(value => value: Boolean)
    override val instanceTagKeys: Option[List[String]] = scala
      .Option(impl.instanceTagKeys())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
  ): zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/DeregisterInstanceTagAttributeRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeregisterInstanceTagAttributeRequest(
    includeAllTagsOfInstance: Optional[Boolean] = Optional.Absent,
    instanceTagKeys: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest = {
    import DeregisterInstanceTagAttributeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
      .builder()
      .optionallyWith(
        includeAllTagsOfInstance.map(value => value: java.lang.Boolean)
      )(_.includeAllTagsOfInstance)
      .optionallyWith(
        instanceTagKeys.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.instanceTagKeys)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly =
    zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest
      .wrap(buildAwsValue())
}
object DeregisterInstanceTagAttributeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest =
      zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest(
        includeAllTagsOfInstance.map(value => value),
        instanceTagKeys.map(value => value)
      )
    def includeAllTagsOfInstance: Optional[Boolean]
    def instanceTagKeys: Optional[List[String]]
    def getIncludeAllTagsOfInstance: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("includeAllTagsOfInstance", includeAllTagsOfInstance)
    def getInstanceTagKeys: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("instanceTagKeys", instanceTagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
  ) extends zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly {
    override val includeAllTagsOfInstance: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.includeAllTagsOfInstance())
        .map(value => value: Boolean)
    override val instanceTagKeys: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceTagKeys())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeregisterInstanceTagAttributeRequest
  ): zio.aws.ec2.model.DeregisterInstanceTagAttributeRequest.ReadOnly =
    new Wrapper(impl)
}
